import { defineDriver } from "./utils/index.mjs";
import LRU from "lru-cache";
export default defineDriver((opts) => {
  const cache = new LRU({
    ...opts,
    maxSize: 500
  });
  return {
    hasItem(key) {
      return cache.has(key);
    },
    getItem(key) {
      return cache.get(key) || null;
    },
    getItemRaw(key) {
      return cache.get(key) || null;
    },
    setItem(key, value) {
      cache.set(key, value);
    },
    setItemRaw(key, value) {
      cache.set(key, value);
    },
    removeItem(key) {
      cache.delete(key);
    },
    getKeys() {
      return Array.from(cache.keys());
    },
    clear() {
      cache.clear();
    },
    dispose() {
      cache.clear();
    }
  };
});
